@@ -1,3 +1,4 @@
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 
@@ -20,15 +21,24 @@ get_scaled(const char *buffer, const char *key)
 	char	      *next;
 	unsigned long long value = 0;
 
-	if ((ptr = strstr(buffer, key)))
+	if (G_LIKELY((ptr = strstr(buffer, key))))
 	{
 		ptr += strlen(key);
 		value = strtoull(ptr, &next, 0);
-		if (strchr(next, 'k'))
-			value *= 1024;
-		else if (strchr(next, 'M'))
-			value *= 1024 * 1024;
-	}
+
+		for ( ; *next; ++next) {
+			if (*next == 'k') {
+				value *= 1024;
+				break;
+			} else if (*next == 'M') {
+				value *= 1024 * 1024;
+				break;
+			}
+		}
+	} else
+		g_warning("Could not read key '%s' in buffer '%s'",
+			  key, buffer);
+
 	return value;
 }
 
@@ -53,13 +63,16 @@ enum TRY_FILE_TO_BUFFER
 	TRY_FILE_TO_BUFFER_READ = -2
 };
 
-int try_file_to_buffer(char *buffer, const char *format, ...)
+int try_file_to_buffer(char *buffer, size_t bufsiz, const char *format, ...)
 {
 	char path[4096];
 	int fd;
 	ssize_t len;
 	va_list pa;
 
+	if (bufsiz <= sizeof(char*))
+	  g_warning("Huhu, bufsiz of %lu looks bad", (gulong)bufsiz);
+
 	va_start(pa, format);
 
 	/* C99 also provides vsnprintf */
@@ -72,7 +85,7 @@ int try_file_to_buffer(char *buffer, const char *format, ...)
 	if((fd = open (path, O_RDONLY)) < 0)
 		return TRY_FILE_TO_BUFFER_OPEN;
 
-	len = read (fd, buffer, BUFSIZ-1);
+	len = read (fd, buffer, bufsiz - 1);
 	close (fd);
 
 	if (len < 0)
@@ -85,9 +98,9 @@ int try_file_to_buffer(char *buffer, const char *format, ...)
 
 
 void
-file_to_buffer(glibtop *server, char *buffer, const char *filename)
+file_to_buffer(glibtop *server, char *buffer, size_t bufsiz, const char *filename)
 {
-	switch(try_file_to_buffer(buffer, filename))
+	switch(try_file_to_buffer(buffer, bufsiz, filename))
 	{
 	case TRY_FILE_TO_BUFFER_OPEN:
 		glibtop_error_io_r (server, "open (%s)", filename);
@@ -105,7 +118,7 @@ read_boot_time(glibtop *server)
 	char buffer[BUFSIZ];
 	char *btime;
 
-	file_to_buffer(server, buffer, "/proc/stat");
+	file_to_buffer(server, buffer, sizeof buffer, "/proc/stat");
 
 	btime = strstr(buffer, "btime");
 
@@ -146,3 +159,48 @@ get_page_size(void)
 
 	return pagesize;
 }
+
+
+
+gboolean
+check_cpu_line(glibtop *server, const char *line, unsigned i)
+{
+	char start[10];
+
+	g_snprintf(start, sizeof start, "cpu%u", i);
+
+	return g_str_has_prefix(line, start);
+}
+
+
+
+gboolean
+has_sysfs(void)
+{
+	static gboolean init;
+	static gboolean sysfs;
+
+	if (G_UNLIKELY(!init)) {
+		sysfs = g_file_test("/sys", G_FILE_TEST_IS_DIR);
+		init = TRUE;
+	}
+
+	return sysfs;
+}
+
+
+
+gboolean safe_readlink(const char *path, char *buf, size_t bufsiz)
+{
+	ssize_t ret;
+
+	ret = readlink(path, buf, bufsiz - 1);
+
+	if (ret == -1) {
+		g_warning("Could not read link %s : %s", path, strerror(errno));
+		return FALSE;
+	}
+
+	buf[ret] = '\0';
+	return TRUE;
+}
